#ifndef __CMDREPLYMOUNTS_H__
#define __CMDREPLYMOUNTS_H__

#include "CmdReply.h"
#include "CmdClientTypes.h"

namespace Aspera {

namespace Command {

    class Buffer;

    /*! \brief
    *  Class to parse and hold the information about one mount point
    */
    class MountPoint {
        private:
            char *fs;
            char *mntPoint;
            char *fsType;
            int64_t total;
            int64_t used;
            int64_t free;
            int64_t fileCount;
            int  errNum;
            char *errStr;

        public:
            MountPoint();
            ~MountPoint();
            void copyIn(MountPoint *aFile);
            void processFileBuffer(Buffer *rawBuffer);
            void printReply();
            MountPoint *nextMount; //Internal use only
            /*! \brief
            *  Returns a pointer to the array of MountPoints
            */
            MountPoint* getMounts();

            void setFs(char *_fs);
            void setMntPoint(char *_mntPoint);
            void setFsType (char *_fsType);
            void setTotalDiskSpace(int64_t _total);
            void setUsedDiskSpace(int64_t _used);
            void setFreeDiskSpace(int64_t _free);
            void setFileCount(int64_t _fileCount);
            void setErrno(int _errNum);
            void setErrstr(char *_errStr);
            /*! \brief
            *  Returns a the filesystem
            */
            char* getFs();
            /*! \brief
            *  Returns the mount point
            */
            char* getMountPoint();
            /*! \brief
            *  Returns a file system type
            */
            char* getFsType();
            /*! \brief
            *  Returns the total disk space in bytes
            */
            int64_t getTotalDiskSpace();
            /*! \brief
            *  Returns the used disk space in bytes
            */
            int64_t getUsedDiskSpace();
            /*! \brief
            *  Returns the free disk space in bytes
            */
            int64_t getFreeDiskSpace();
            /*! \brief
            *  Returns the error number
            */
            int getErrNum();
            /*! \brief
            *  Returns the error description
            */
            char* getErrStr();
    };

    /*! \brief
    *  Class to parse and hold the list of mount points
    */
    class CmdReplyMounts : public CmdReply
    {
        private:

        const static char Fs        = 0x01;
        const static char MntPoint  = 0x02;
        const static char FsType    = 0x03;
        const static char Total     = 0x04;
        const static char Used      = 0x05;
        const static char Free      = 0x06;
        const static char FileCount = 0x07;
        const static char Errno     = 0x08;
        const static char Errstr    = 0x09;

        int mountsCount;
        MountPoint *mountsListHead;
        MountPoint *mountsListTail;

        public:
            CmdReplyMounts(CommandClientImpl *cc);
            ~CmdReplyMounts();
            int processMsgBuffer(Buffer *rawBuffer);
            void printReply();
            /*! \brief
            *  Returns a pointer to the array of MountPoint objects
            */
            MountPoint* getMounts();
            /*! \brief
            *  Returns the no. of mountpoint returned by the remote server
            */
            int getMountCount(); //Does this need to be u_int32_t
    };
}
}
#endif
